@@ -25,62 +25,14 @@ our @ISA;
 our ($n, %by_index, @attributes, %is_attribute);
 use Audio::Nama::Object qw( 
 
-
-
-
-
-
 		n					
-
 		ops_list			
-							
-							
-							
         ops_data			
-							
-							
 		inserts_data		
-							
-							
-							
-							
 		region				
-							
 		attrib 				
-
 		class				
 
-
-
-	
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
 		);
 @attributes = qw(
 			name
@@ -94,10 +46,42 @@ use Audio::Nama::Object qw(
 			track_name
 			track_version_result 
 			track_version_original
+			track_target_original
 			insert				
 			track_cache	
+			track_target
 	) ;
 
+### 	attributes for searching, sorting, used by external functions
+# 		name				# for user-defined effect chains
+# 
+# 		bypass				# used for identifying effect bypass (obsolete)
+# 		id					# effect id, for storing single effect with controllers
+# 							# for bypass (probably obsolete)	
+# 
+# 		project				# true value identifies project-specific effect chain
+# 
+# 		global				# true value identified global effect chain,
+# 							# not project specific, usually user-defined
+# 
+# 		profile				# name of associated effect profile
+# 
+# 		user				# true value identifies user created effect chain
+# 
+# 		system				# true value identifies system generated effect chain
+# 
+# 		track_name			# applies to a track of this name
+# 
+# 		track_version_result 	# WAV version of track after caching
+# 
+# 		track_version_original 	# WAV version of track before caching 
+# 
+# 		insert				# true value identifies belonging to an insert
+# 		
+# 		track_cache			# true value identifies belonging to track caching
+#
+# 		track_target_original #	WAV files were from this track
+
 %is_attribute = map{ $_ => 1 } @attributes;
 initialize();
 
@@ -108,7 +92,7 @@ sub is_controller {
 	my ($self, $id) = @_;
 	$self->{ops_data}->{$id}->{belongs_to}
 }
-sub parent : lvalue {
+sub parent_id : lvalue {
 	my ($self, $id) = @_;
 	$self->{ops_data}->{$id}->{belongs_to}
 }
@@ -304,7 +288,7 @@ sub add_ops {
 			chain  		=> $track->n,
 			type   		=> $self->type($_),
 			params 		=> $self->params($_),
-			parent		=> $self->parent($_),
+			parent		=> $self->parent_id($_),
 		};
 
 		
@@ -329,7 +313,7 @@ sub add_ops {
 		if ( $new_id ne $orig_id)
 		# re-write all controllers to belong to new id
 		{
-			map{ $self->parent($_) =~ s/^$orig_id$/$new_id/  } @{$self->ops_list}
+			map{ $self->parent_id($_) =~ s/^$orig_id$/$new_id/  } @{$self->ops_list}
 		}
 		
 	} @ops_list;
@@ -356,6 +340,7 @@ sub add_inserts {
 }
 sub add_region {
 	my ($self, $track) = @_;
+	# there is also a check in uncache track
 	Audio::Nama::throw($track->name.": track already has region definition\n",
 		"failed to apply region @$self->{region}\n"), return
 		if $track->is_region;
