@@ -294,12 +294,6 @@ sub initialize_interfaces {
 
 	read_config(global_config());  # from .namarc if we have one
 
-	# overwrite default hotkey bindings by those in .namarc 
-	$config->{hotkeys} = {
-		%{json_in(get_data_section 'hotkey_bindings') },
-		%{$config->{hotkeys} } 
-	};
-	
 	logpkg(__FILE__,__LINE__,'debug',sub{"Config data\n".Dumper $config});
 	
 	select_ecasound_interface();
